==> haskell-monad-loops-0.4.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-loops
version:              0.4.3
visibility:           public
id:                   monad-loops-0.4.3-1E2zS5vP8vC8dPxRpEhLxP
key:                  monad-loops-0.4.3-1E2zS5vP8vC8dPxRpEhLxP
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/monad-loops
synopsis:             Monadic loops
description:
    Some useful control operators for looping.

    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.

    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.

category:             Control
abi:                  265f197a2bdb08b54506e0828a4c93c0
exposed:              True
exposed-modules:      Control.Monad.Loops
import-dirs:          /usr/lib/ghc-8.8.3/site-local/monad-loops-0.4.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/monad-loops-0.4.3
hs-libraries:         HSmonad-loops-0.4.3-1E2zS5vP8vC8dPxRpEhLxP
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html:         /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-loops-0.4.3-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-loops.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-loops
version:              0.4.3
visibility:           public
id:                   monad-loops-0.4.3-8vl2D03xZPMKQkyzzvP1nU
key:                  monad-loops-0.4.3-8vl2D03xZPMKQkyzzvP1nU
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/monad-loops
synopsis:             Monadic loops
description:
    Some useful control operators for looping.

    New in 0.4: STM loop operators have been split into a
    new package instead of being conditionally-built.

    New in 0.3.2.0: various functions for traversing lists and
    computing minima/maxima using arbitrary procedures to compare
    or score the elements.

category:             Control
abi:                  04ab94c0dab7981857ab7aeb17033c92
exposed:              True
exposed-modules:      Control.Monad.Loops
import-dirs:          /usr/lib/ghc-8.10.1/site-local/monad-loops-0.4.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/monad-loops-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/monad-loops-0.4.3
hs-libraries:         HSmonad-loops-0.4.3-8vl2D03xZPMKQkyzzvP1nU
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-monad-loops/html/monad-loops.haddock
haddock-html:         /usr/share/doc/haskell-monad-loops/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
